@@ -2,18 +2,23 @@
 #' @description Testing the robustness of \code{\link{search.trend}}
 #'   (\cite{Castiglione et al. 2019a}), \code{\link{search.shift}}
 #'   (\cite{Castiglione et al. 2018}),  \code{\link{search.conv}}
-#'   (\cite{Castiglione et al. 2019b}), and \code{\link{PGLS_fossil}}
-#'    results to sampling effects and phylogenetic uncertainty.
+#'   (\cite{Castiglione et al. 2019b}), and \code{\link{PGLS_fossil}} results to
+#'   sampling effects and phylogenetic uncertainty.
 #' @usage
-#' overfitRR(RR,y,s=0.25,swap.args=NULL,trend.args=NULL,shift.args=NULL,conv.args=NULL,
-#' pgls.args=NULL,aces=NULL,x1=NULL,aces.x1=NULL,cov=NULL,rootV=NULL,nsim=100,clus=.5)
+#' overfitRR(RR,y,phylo.list=NULL,s=0.25,swap.args=NULL,trend.args=NULL,shift.args=NULL,
+#' conv.args=NULL, pgls.args=NULL,aces=NULL,x1=NULL,aces.x1=NULL,cov=NULL,
+#' rootV=NULL,nsim=100,clus=.5)
 #' @param RR an object produced by \code{\link{RRphylo}}.
 #' @param y a named vector of phenotypes.
+#' @param phylo.list a list (or multiPhylo) of alternative phylogenies to be
+#'   tested.
 #' @param s the percentage of tips to be cut off. It is set at 25\% by default.
+#'   If \code{phylo.list} is provided, this argument is ignored.
 #' @param swap.args a list of arguments to be passed to the function
 #'   \code{\link{swapONE}}, including \code{list(si=NULL,si2=NULL,}
 #'   \code{node=NULL)}. If \code{swap.arg} is unspecified, the function
-#'   automatically sets both \code{si} and \code{si2} to 0.1.
+#'   automatically sets both \code{si} and \code{si2} to 0.1. If
+#'   \code{phylo.list} is provided, swapping is not performed.
 #' @param trend.args a list of arguments specific to the function
 #'   \code{search.trend}, including \code{list(node=NULL,x1.residuals=FALSE)}.
 #'   If a trend for the whole tree is to be tested, type \code{trend.args =
@@ -27,11 +32,12 @@
 #'   the same time.
 #' @param pgls.args a list of arguments specific to the function
 #'   \code{PGLS_fossil}, including \code{list(modform,} \code{data,
-#'   tree=FALSE,RR=TRUE)}. If \code{tree=TRUE}, \code{PGLS_fossil} is performed
-#'   by using the RRphylo output tree as \code{tree} argument. If
-#'   \code{RR=TRUE}, \code{PGLS_fossil} is performed by using the RRphylo
-#'   output as \code{RR} argument. Arguments \code{tree} and \code{RR} can be
-#'   \code{TRUE} at the same time.
+#'   tree=FALSE,RR=TRUE,...)}. If \code{tree=TRUE}, \code{PGLS_fossil} is
+#'   performed by using the RRphylo output tree as \code{tree} argument. If
+#'   \code{RR=TRUE}, \code{PGLS_fossil} is performed by using the RRphylo output
+#'   as \code{RR} argument. Arguments \code{tree} and \code{RR} can be
+#'   \code{TRUE} at the same time. \code{...} are further argument passed to
+#'   \code{PGLS_fossil}.
 #' @param aces if used to produce the \code{RR} object, the vector of those
 #'   ancestral character values at nodes known in advance must be specified.
 #'   Names correspond to the nodes in the tree.
@@ -55,7 +61,7 @@
 #'   default.
 #' @param clus the proportion of clusters to be used in parallel computing. To
 #'   run the single-threaded version of \code{overfitRR} set \code{clus} = 0.
-#' @return The function returns a 'RRphyloList' objec containing:
+#' @return The function returns a 'RRphyloList' object containing:
 #' @return \strong{$mean.sampling} the mean proportion of species actually
 #'   removed from the tree over the iterations.
 #' @return \strong{$tree.list} a 'multiPhylo' list including the trees generated
@@ -70,26 +76,32 @@
 #'   \code{search.conv} performed under \code{clade} and \code{state}
 #'   conditions. If a node pair is specified within \code{conv.args}, the
 #'   \code{$clade} object contains the percentage of simulations producing
-#'   significant p-values for convergence between the clades. If a state vector
-#'   is supplied within \code{conv.args}, the object \code{$state} contains the
-#'   percentage of simulations producing significant p-values for convergence
-#'   within (single state) or between states (multiple states).
+#'   significant p-values for convergence between the clades, and the proportion
+#'   of tested trees (i.e. where the clades identity was preserved; always 1 if
+#'   no \code{phylo.list} is supplied). If a state vector is supplied within
+#'   \code{conv.args}, the object \code{$state} contains the percentage of
+#'   simulations producing significant p-values for convergence within (single
+#'   state) or between states (multiple states).
 #' @return \strong{$shift.results} a list including results for
 #'   \code{search.shift} performed under \code{clade} and \code{sparse}
 #'   conditions. If one or more nodes are specified within \code{shift.args},
 #'   the \code{$clade} object contains for each node the percentage of
 #'   simulations producing significant p-value separated by shift sign, and the
 #'   same figures by considering all the specified nodes as evolving under a
-#'   single rate (all.clades).If a state vector is supplied within
-#'   \code{shift.args}, the object \code{$sparse} contains the percentage of
-#'   simulations producing significant p-value separated by shift sign
-#'   ($p.states).
+#'   single rate (all.clades). For each node the proportion of tested trees
+#'   (i.e. where the clade identity was preserved; always 1 if no
+#'   \code{phylo.list} is supplied) is also indicated. If a state vector is
+#'   supplied within \code{shift.args}, the object \code{$sparse} contains the
+#'   percentage of simulations producing significant p-value separated by shift
+#'   sign ($p.states).
 #' @return \strong{$trend.results} a list including the percentage of
 #'   simulations showing significant p-values for phenotypes versus age and
 #'   absolute rates versus age regressions for the entire tree separated by
 #'   slope sign ($tree). If one or more nodes are specified within
 #'   \code{trend.args}, the list also includes the same results at nodes ($node)
-#'   and the results for comparison between nodes ($comparison).
+#'   and the results for comparison between nodes ($comparison). For each node the proportion
+#'   of tested trees (i.e. where the clade identity was preserved; always 1 if
+#'   no \code{phylo.list} is supplied) is also indicated.
 #' @return \strong{$pgls.results} two 'RRphyloList' objects including results of
 #'   \code{PGLS_fossil} performed by using the phylogeny as it is (\code{$tree})
 #'   or rescaled according to the \code{RRphylo} rates (\code{$RR}).
@@ -110,6 +122,16 @@
 #'   shuffles the tree by using the function \code{\link{swapONE}}. Thereby,
 #'   both the potential for overfit and phylogenetic uncertainty are accounted
 #'   for straight away.
+#'
+#'   Otherwise, a list of alternative phylogenies can be supplied to
+#'   \code{overfitRR}. In this case subsampling and swapping arguments are
+#'   ignored, and robustness testing is performed on the alternative topologies
+#'   as they are. If a clade has to be tested either in \code{search.shift},
+#'   \code{search.trend}, or \code{search.conv}, the function scans each
+#'   alternative topology searching for the corresponding clade. If the species
+#'   within such clade on the alternative topology differ more than 10% from the
+#'   species within the clade in the original tree, the identity of the clade is
+#'   considered disrupted and the test is not performed.
 #' @export
 #' @seealso \href{../doc/overfitRR.html}{\code{overfitRR} vignette} ;
 #'   \href{../doc/search.trend.html}{\code{search.trend} vignette} ;
@@ -150,10 +172,8 @@
 #' RRphylo(tree=treeptero,y=log(massptero))->RRptero
 #'
 #' # Case 1 search.shift under both "clade" and "sparse" condition
-#' search.shift(RR=dinoRates, status.type= "clade",
-#'              filename=paste(tempdir(),"SSnode",sep="/"))->SSnode
-#' search.shift(RR=dinoRates, status.type= "sparse", state=statedino,
-#'              filename=paste(tempdir(),"SSstate",sep="/"))->SSstate
+#' search.shift(RR=dinoRates, status.type= "clade")->SSnode
+#' search.shift(RR=dinoRates, status.type= "sparse", state=statedino)->SSstate
 #'
 #' overfitRR(RR=dinoRates,y=massdino,swap.args =list(si=0.2,si2=0.2),
 #'           shift.args = list(node=rownames(SSnode$single.clades),state=statedino),
@@ -187,13 +207,12 @@
 #' c(acemass.multi,masscet.multi)->x1.mass
 #'
 #' RRphylo(tree=treecet.multi,y=brainmasscet,x1=x1.mass)->RRmulti
-#' search.trend(RR=RRmulti, y=brainmasscet,x1=x1.mass,clus=cc,
-#'              filename=paste(tempdir(),"STtree",sep="/"))->STcet
+#' search.trend(RR=RRmulti, y=brainmasscet,x1=x1.mass,clus=cc)->STcet
 #' overfitRR(RR=RRmulti,y=brainmasscet,trend.args = list(),
 #'           x1=x1.mass,nsim=10,clus=cc)->orr.st3
 #'
 #' search.trend(RR=RRmulti, y=brainmasscet,x1=x1.mass,x1.residuals=TRUE,
-#'              clus=cc,filename=paste(tempdir(),"STcet.resi",sep="/"))->STcet.resi
+#'              clus=cc)->STcet.resi
 #' overfitRR(RR=RRmulti,y=brainmasscet,trend.args = list(x1.residuals=TRUE),
 #'           x1=x1.mass,nsim=10,clus=cc)->orr.st4
 #'
@@ -204,8 +223,7 @@
 #' DataFelids$statefel->statefel
 #'
 #' RRphylo(tree=treefel,y=PCscoresfel,clus=cc)->RRfel
-#' search.conv(RR=RRfel, y=PCscoresfel, min.dim=5, min.dist="node9",
-#'             filename = paste(tempdir(),"SC.clade",sep="/"),clus=cc)->SC.clade
+#' search.conv(RR=RRfel, y=PCscoresfel, min.dim=5, min.dist="node9",clus=cc)->SC.clade
 #' as.numeric(c(rownames(SC.clade[[1]])[1],as.numeric(as.character(SC.clade[[1]][1,1]))))->conv.nodes
 #'
 #' overfitRR(RR=RRfel, y=PCscoresfel,conv.args =
@@ -240,6 +258,7 @@
 #'
 #' }
 overfitRR<-function(RR,y,
+                    phylo.list=NULL,
                     s=0.25,
                     swap.args=NULL,
                     trend.args=NULL,
@@ -247,10 +266,9 @@ overfitRR<-function(RR,y,
                     conv.args=NULL,
                     pgls.args=NULL,
                     aces=NULL,x1=NULL,aces.x1=NULL,cov=NULL,rootV=NULL,nsim=100,
-                    clus=.5)
+                    clus=0.5)
 {
   # require(phytools)
-  # require(geiger)
   # require(ddpcr)
   # require(rlist)
 
@@ -266,14 +284,23 @@ overfitRR<-function(RR,y,
   RR$aces->y.ace
   tree$node.label<-rownames(y.ace)
 
-  if(!is.null(swap.args)){
-    if(is.null(swap.args$si)) si<-0.1 else si<-swap.args$si
-    if(is.null(swap.args$si2)) si2<-0.1 else si2<-swap.args$si2
-    if(is.null(swap.args$node)) swap.node<-NULL else swap.node<-swap.args$node
-  }else{
-    si<-0.1
-    si2<-0.1
+  if(!is.null(phylo.list)){
+    if(!is.null(swap.args)) warning("Swapping is not performed if a list of alternative phylogenies is provided",immediate.=TRUE)
+    s<-0
+    si<-0
+    si2<-0
     swap.node<-NULL
+    nsim<-length(phylo.list)
+  }else{
+    if(!is.null(swap.args)){
+      if(is.null(swap.args$si)) si<-0.1 else si<-swap.args$si
+      if(is.null(swap.args$si2)) si2<-0.1 else si2<-swap.args$si2
+      if(is.null(swap.args$node)) swap.node<-NULL else swap.node<-swap.args$node
+    }else{
+      si<-0.1
+      si2<-0.1
+      swap.node<-NULL
+    }
   }
 
   if(!is.null(trend.args)){
@@ -315,6 +342,7 @@ overfitRR<-function(RR,y,
     pgls.data<-pgls.args$data
     if(pgls.args$tree) pgls.tree<-pgls.args$tree else pgls.tree<-NULL
     if(pgls.args$RR) pgls.RR<-pgls.args$RR else pgls.RR<-NULL
+    pgls.args<-pgls.args[which(!names(pgls.args)%in%c("modform","data","tree","RR"))]
   }else{
     modform<-NULL
     pgls.data<-NULL
@@ -371,7 +399,8 @@ overfitRR<-function(RR,y,
       sample(samtips,round(Ntip(tree)*sx,0))->offs
     }
 
-    suppressWarnings(swapONE(tree,si=si,si2=si2,node=swap.node,plot.swap=FALSE)[[1]])->tree.swap
+    if(!is.null(phylo.list)) phylo.list[[k]]->tree.swap else
+      suppressWarnings(swapONE(tree,si=si,si2=si2,node=swap.node,plot.swap=FALSE)[[1]])->tree.swap
 
     y[match(tree.swap$tip.label,rownames(y)),,drop=FALSE]->y
 
@@ -393,17 +422,19 @@ overfitRR<-function(RR,y,
 
     1-(Ntip(treecut)/Ntip(tree))->real.s[k]
 
-    if(!is.null(cov)) {
-      cov[match(c(tree.swap$node.label,tree.swap$tip.label), names(cov))]->cov
-      cov[match(c(rownames(y.acecut),rownames(ycut)),names(cov))]->covcut
-      names(covcut)[1:Nnode(treecut)]<-seq((Ntip(treecut)+1),(Ntip(treecut)+Nnode(treecut)))
+    if(!is.null(cov)){
+      treedataMatch(treecut,cov)$y->covcut
+      c(RRphylo(treecut,covcut)$aces[,1],covcut)->covcut
+      # cov[match(c(rownames(y.acecut),rownames(ycut)),names(cov))]->covcut
+      # names(covcut)[1:Nnode(treecut)]<-seq((Ntip(treecut)+1),(Ntip(treecut)+Nnode(treecut)))
     }else covcut<-NULL
 
     if(!is.null(x1)) {
       as.matrix(x1)->x1
-      x1[match(c(tree.swap$node.label,tree.swap$tip.label),rownames(x1)),,drop=FALSE]->x1
-      x1[match(c(rownames(y.acecut),rownames(ycut)),rownames(x1)),,drop=FALSE]->x1cut
-      rownames(x1cut)[1:Nnode(treecut)]<-seq((Ntip(treecut)+1),(Ntip(treecut)+Nnode(treecut)))
+      treedataMatch(treecut,x1)$y->x1cut
+      rbind(RRphylo(treecut,x1cut)$aces,x1cut)->x1cut
+      # x1[match(c(rownames(y.acecut),rownames(ycut)),rownames(x1)),,drop=FALSE]->x1cut
+      # rownames(x1cut)[1:Nnode(treecut)]<-seq((Ntip(treecut)+1),(Ntip(treecut)+Nnode(treecut)))
     }else x1cut<-NULL
 
     if(!is.null(aces)){
@@ -412,11 +443,17 @@ overfitRR<-function(RR,y,
 
       drop<-c()
       for(i in 1:nrow(aces)) {
-        if(length(which(tips(tree,rownames(aces)[i])%in%treecut$tip.label))>1)
-          getMRCA(treecut,tips(tree,rownames(aces)[i])[which(tips(tree,rownames(aces)[i])%in%treecut$tip.label)])->rownames(acescut)[i] else
-            c(drop,i)->drop
+        if(length(which(tips(tree,rownames(aces)[i])%in%treecut$tip.label))>1){
+          getMRCA(treecut,tips(tree,rownames(aces)[i])[which(tips(tree,rownames(aces)[i])%in%treecut$tip.label)])->newN
+          if(!is.null(phylo.list)){
+            length(tips(treecut,newN))/length(tips(tree,rownames(aces)[i]))->sh.tips
+            if(sh.tips<=1.1&sh.tips>=0.9) newN->rownames(acescut)[i] else c(drop,i)->drop
+          }else newN->rownames(acescut)[i]
+          # getMRCA(treecut,tips(tree,rownames(aces)[i])[which(tips(tree,rownames(aces)[i])%in%treecut$tip.label)])->rownames(acescut)[i]
+        }else c(drop,i)->drop
       }
       if(length(drop>0)) acescut[-drop,]->acescut
+      if(is.null(nrow(acescut))) acescut<-NULL
     }else acescut<-NULL
 
     if(!is.null(aces.x1)){
@@ -424,24 +461,49 @@ overfitRR<-function(RR,y,
       aces.x1->aces.x1cut
       drop<-c()
       for(i in 1:nrow(aces.x1)) {
-        if(length(which(tips(tree,rownames(aces.x1)[i])%in%treecut$tip.label))>1)
-          getMRCA(treecut,tips(tree,rownames(aces.x1)[i])[which(tips(tree,rownames(aces.x1)[i])%in%treecut$tip.label)])->rownames(aces.x1cut)[i] else
-            c(drop,i)->drop
+        if(length(which(tips(tree,rownames(aces.x1)[i])%in%treecut$tip.label))>1){
+          getMRCA(treecut,tips(tree,rownames(aces.x1)[i])[which(tips(tree,rownames(aces.x1)[i])%in%treecut$tip.label)])->newN1
+          if(!is.null(phylo.list)){
+            length(tips(treecut,newN1))/length(tips(tree,rownames(aces.x1)[i]))->sh.tips
+            if(sh.tips<=1.1&sh.tips>=0.9) newN1->rownames(aces.x1cut)[i] else c(drop,i)->drop
+          }else newN1->rownames(aces.x1cut)[i]
+          # getMRCA(treecut,tips(tree,rownames(aces.x1)[i])[which(tips(tree,rownames(aces.x1)[i])%in%treecut$tip.label)])->rownames(aces.x1cut)[i]
+        }else c(drop,i)->drop
       }
       if(length(drop>0)) aces.x1cut[-drop,,drop=FALSE]->aces.x1cut
-
+      if(is.null(nrow(aces.x1cut))) aces.x1cut<-NULL
     }else aces.x1cut<-NULL
 
     if(!is.null(trend.node)){
       trend.node.cut<-array()
-      for(i in 1:length(trend.node)) getMRCA(treecut,tips(tree,trend.node[i])[which(tips(tree,trend.node[i])%in%treecut$tip.label)])->trend.node.cut[i]
+      for(i in 1:length(trend.node)) {
+        getMRCA(treecut,tips(tree,trend.node[i])[which(tips(tree,trend.node[i])%in%treecut$tip.label)])->trN
+        if(!is.null(phylo.list)){
+          length(tips(treecut,trN))/length(tips(tree,trend.node[i]))->sh.tips
+          if(sh.tips<=1.1&sh.tips>=0.9) trN->trend.node.cut[i] else NA->trend.node.cut[i]
+        } else trN->trend.node.cut[i]
+        # getMRCA(treecut,tips(tree,trend.node[i])[which(tips(tree,trend.node[i])%in%treecut$tip.label)])->trend.node.cut[i]
+      }
       data.frame(trend.node,trend.node.cut)->trend.node.match[[k]]
+
+      trend.node.cut[which(!is.na(trend.node.cut))]->trend.node.cut
+      if(length(trend.node.cut)==0) trend.node.cut<-NULL
     }else trend.node.cut<-NULL
 
     if(!is.null(shift.node)){
       shift.node.cut<-array()
-      for(i in 1:length(shift.node)) getMRCA(treecut,tips(tree,shift.node[i])[which(tips(tree,shift.node[i])%in%treecut$tip.label)])->shift.node.cut[i]
+      for(i in 1:length(shift.node)){
+        getMRCA(treecut,tips(tree,shift.node[i])[which(tips(tree,shift.node[i])%in%treecut$tip.label)])->shN
+        if(!is.null(phylo.list)){
+          length(tips(treecut,shN))/length(tips(tree,shift.node[i]))->sh.tips
+          if(sh.tips<=1.1&sh.tips>=0.9) shN->shift.node.cut[i] else NA->shift.node.cut[i]
+        } else shN->shift.node.cut[i]
+      }
+      # getMRCA(treecut,tips(tree,shift.node[i])[which(tips(tree,shift.node[i])%in%treecut$tip.label)])->shift.node.cut[i]
       data.frame(shift.node,shift.node.cut)->shift.node.match[[k]]
+      shift.node.cut[which(!is.na(shift.node.cut))]->shift.node.cut
+      if(length(shift.node.cut)==0) shift.node.cut<-NULL
+
     }
 
     if(!is.null(shift.state)) {
@@ -451,8 +513,16 @@ overfitRR<-function(RR,y,
 
     if(!is.null(conv.node)){
       conv.node.cut<-array()
-      for(i in 1:length(conv.node)) getMRCA(treecut,tips(tree,conv.node[i])[which(tips(tree,conv.node[i])%in%treecut$tip.label)])->conv.node.cut[i]
-      data.frame(conv.node,conv.node.cut)->conv.node.match[[k]]
+      for(i in 1:length(conv.node)){
+        getMRCA(treecut,tips(tree,conv.node[i])[which(tips(tree,conv.node[i])%in%treecut$tip.label)])->scN
+        if(!is.null(phylo.list)){
+          length(tips(treecut,scN))/length(tips(tree,conv.node[i]))->sh.tips
+          if(sh.tips<=1.1&sh.tips>=0.9) scN->conv.node.cut[i] else NA->conv.node.cut[i]
+        } else scN->conv.node.cut[i]
+        if(any(is.na(conv.node.cut))) conv.node.cut<-NULL
+      }
+      # getMRCA(treecut,tips(tree,conv.node[i])[which(tips(tree,conv.node[i])%in%treecut$tip.label)])->conv.node.cut[i]
+      if(!is.null(conv.node.cut)) data.frame(conv.node,conv.node.cut)->conv.node.match[[k]] else NULL->conv.node.match[[k]]
     }
 
     if(!is.null(conv.state)) {
@@ -470,12 +540,14 @@ overfitRR<-function(RR,y,
 
     RRphylo(treecut,ycut,aces=acescut,x1=x1cut,aces.x1=aces.x1cut,cov=covcut,rootV = rootVcut,clus=clus)->RRcut->RR.list[[k]]
     if(trend|!is.null(trend.node)) ddpcr::quiet(search.trend(RRcut,ycut,x1=x1cut,x1.residuals = trend.x1.residuals,node=trend.node.cut,cov=covcut,clus=clus)->stcut->STcut[[k]],all=TRUE)
-    if(!is.null(shift.node)) ddpcr::quiet(search.shift(RRcut,status.type="clade",node=shift.node.cut,filename=tempdir())->sscut->SScut[[k]],all=TRUE)
-    if(!is.null(shift.state)) ddpcr::quiet(search.shift(RRcut,status.type="sparse",state=shift.state.cut,filename=tempdir())->sscut->SScutS[[k]],all=TRUE)
-    if(!is.null(conv.node)) ddpcr::quiet(search.conv(RR=RRcut,y=ycut,nodes=conv.node.cut,aceV=acescut,clus=clus,filename=tempdir())->sccut->SCcut[[k]],all=TRUE)
-    if(!is.null(conv.state)) ddpcr::quiet(search.conv(tree=treecut,y=ycut,state=conv.state.cut,aceV=acescut,declust=conv.declust,clus=clus,filename=tempdir())->sccut->SCcutS[[k]],all=TRUE)
-    if(!is.null(pgls.tree)) ddpcr::quiet(PGLS_fossil(modform,data=pgls.datacut,tree=treecut)->PGLScut[[k]],all=TRUE)
-    if(!is.null(pgls.RR)) ddpcr::quiet(PGLS_fossil(modform,data=pgls.datacut,tree=RRcut$tree,RR=RRcut)->PGLScutRR[[k]],all=TRUE)
+    if(!is.null(shift.node)&&!is.null(shift.node.cut)) ddpcr::quiet(search.shift(RRcut,status.type="clade",node=shift.node.cut)->sscut->SScut[[k]],all=TRUE)
+    if(!is.null(shift.state)) ddpcr::quiet(search.shift(RRcut,status.type="sparse",state=shift.state.cut)->sscut->SScutS[[k]],all=TRUE)
+    if(!is.null(conv.node)&&any(!is.na(conv.node.cut))) ddpcr::quiet(search.conv(RR=RRcut,y=ycut,nodes=na.omit(conv.node.cut),aceV=acescut,clus=clus)->sccut->SCcut[[k]],all=TRUE)
+    if(!is.null(conv.state)) ddpcr::quiet(search.conv(tree=treecut,y=ycut,state=conv.state.cut,aceV=acescut,declust=conv.declust,clus=clus)->sccut->SCcutS[[k]],all=TRUE)
+    # if(!is.null(pgls.tree)) ddpcr::quiet(PGLS_fossil(modform,data=pgls.datacut,tree=treecut)->PGLScut[[k]],all=TRUE)
+    # if(!is.null(pgls.RR)) ddpcr::quiet(PGLS_fossil(modform,data=pgls.datacut,tree=RRcut$tree,RR=RRcut)->PGLScutRR[[k]],all=TRUE)
+    if(!is.null(pgls.tree)) ddpcr::quiet(do.call(PGLS_fossil,c(list(modform=modform,data=pgls.datacut,tree=treecut),pgls.args))->PGLScut[[k]],all=TRUE)
+    if(!is.null(pgls.RR)) ddpcr::quiet(do.call(PGLS_fossil,c(list(modform=modform,data=pgls.datacut,RR=RRcut),pgls.args))->PGLScutRR[[k]],all=TRUE)
 
     RRcut$aces[1,]->rootlist[[k]]
     summary(lm(y.acecut~RRcut$aces))->acefit[[k]]
@@ -497,30 +569,32 @@ overfitRR<-function(RR,y,
   }
 
   if(!is.null(shift.node)){
-    if(length(SScut[[1]])>=2){
-      unlist(lapply(lapply(SScut,"[[",1),function(x) x[,2]))-> p.ran.whole
-      c(length(which(p.ran.whole>=0.975))/nsim,length(which(p.ran.whole<=0.025))/nsim)->p.shift.whole
-      do.call(rbind,mapply(x=lapply(SScut,"[[",2),xx=shift.node.match,function(x,xx){
-        xx[match(rownames(x),xx[,2]),1]->rownames(x)
-        t(x[match(xx[,1],rownames(x)),2,drop=FALSE])
-      },SIMPLIFY = FALSE))-> p.ran
-      #do.call(rbind,lapply(lapply(SScut,"[[",2),function(x) x[,2]))-> p.ran
-      cbind(apply(p.ran,2,function(x) length(which(x>=0.975)))/nsim,
-            apply(p.ran,2,function(x) length(which(x<=0.025)))/nsim)->p.shift
-      rbind(p.shift.whole,p.shift)->shift.res.clade
-      # rownames(shift.res.clade)<-c("all.clades",shift.node)
-      rownames(shift.res.clade)[1]<-"all.clades"
-      colnames(shift.res.clade)<-c("p.shift+","p.shift-")
+    mapply(a=shift.node.match,b=SScut,function(a,b){
+      a[match(rownames(b$single.clade),a[,2]),1]->rownames(b$single.clade)
+      b$single.clade
+    },SIMPLIFY = FALSE)->singles
 
-    }else{
-      sapply(lapply(SScut,"[[",1),"[[",2)-> p.ran
-      matrix(c(length(which(p.ran>=0.975))/nsim,length(which(p.ran<=0.025))/nsim),ncol=2)->shift.res.clade
-      rownames(shift.res.clade)<-shift.node
-      colnames(shift.res.clade)<-c("p.shift+","p.shift-")
+    t(sapply(shift.node,function(k){
+      t(sapply(singles,function(j) {
+        if(any(as.numeric(rownames(j))==k)) j[which(as.numeric(rownames(j))==k),] else c(NA,NA)
+      }))->pran
+      pran[which(!is.na(pran[,1])),]->pran
+      cbind(length(which(pran[,2]>=0.975))/nrow(pran),length(which(pran[,2]<=0.025))/nrow(pran),nrow(pran)/nsim)
+    }))->shift.res.clade
+    rownames(shift.res.clade)<-shift.node
+    colnames(shift.res.clade)<-c("p.shift+","p.shift-","tested.trees")
+
+    lapply(SScut,function(j) j$all.clades)->allcla
+    if(!all(is.null(allcla))){
+      do.call(rbind, allcla)->allcla
+      rbind(cbind(length(which(allcla$p.value>=0.975))/nrow(allcla),
+                  length(which(allcla$p.value<=0.025))/nrow(allcla),nrow(allcla)/nsim),
+            shift.res.clade)->shift.res.clade
+      rownames(shift.res.clade)[1]<-"all.clades"
     }
   }else shift.res.clade<-NULL
 
-  if(is.null(shift.state)==FALSE){
+  if(!is.null(shift.state)){
     p.shift<-matrix(ncol=2,nrow=nrow(SScutS[[1]][[1]]))
     for(i in 1:nrow(SScutS[[1]][[1]])){
       unlist(lapply(lapply(SScutS,"[[",1),function(x) x[i,2]))->pr
@@ -569,33 +643,51 @@ overfitRR<-function(RR,y,
     p.trend->whole.tree.res
 
     if(!is.null(trend.node)){
-      lapply(STcut,"[[",4)->phen.node
-      lapply(STcut,"[[",5)->rat.node
+      mapply(a=trend.node.match,b=lapply(STcut,"[[",4),function(a,b){
+        a[match(names(b),a[,2]),1]->names(b)
+        b
+      },SIMPLIFY = FALSE)->phen.node
+
+      mapply(a=trend.node.match,b=lapply(STcut,"[[",5),function(a,b){
+        a[match(names(b),a[,2]),1]->names(b)
+        b
+      },SIMPLIFY = FALSE)->rat.node
 
       p.phen.node<-list()
       p.rate.node<-list()
-      for(i in 1:length(trend.node)){ ### Results nodes ####
-        p.phen.node.y<-matrix(ncol=6,nrow=iter)
-        p.rate.node.y<-matrix(ncol=4,nrow=iter)
-        for(j in 1:iter){
-          as.data.frame(do.call(rbind,lapply(lapply(phen.node,"[[",i),function(x) x[j,])))->pnod
-          as.data.frame(do.call(rbind,lapply(lapply(rat.node,"[[",i),function(x) x[j,])))->rnod
+      for(k in 1:length(trend.node)){
+        lapply(phen.node,function(j) {
+          if(any(as.numeric(names(j))==trend.node[k])) j[[which(as.numeric(names(j))==trend.node[k])]] else NA
+        })->pran
+        pran[which(!sapply(pran,function(w) all(is.na(w))))]->phen.pran
 
-          c(sum(pnod$slope>0&pnod$p.slope>=0.975)/nsim,
-            sum(pnod$slope>0&pnod$p.slope<=0.025)/nsim,
-            sum(pnod$slope<0&pnod$p.slope>=0.975)/nsim,
-            sum(pnod$slope<0&pnod$p.slope<=0.025)/nsim,
-            sum(pnod$emm.difference>0&pnod$p.emm<=0.05)/nsim,
-            sum(pnod$emm.difference<0&pnod$p.emm<=0.05)/nsim)->p.phen.node.y[j,]
+        lapply(rat.node,function(j) {
+          if(any(as.numeric(names(j))==trend.node[k])) j[[which(as.numeric(names(j))==trend.node[k])]] else NA
+        })->pran
+        pran[which(!sapply(pran,function(w) all(is.na(w))))]->rat.pran
 
-          c(sum(rnod$emm.difference>0&rnod$p.emm<=0.05)/nsim,
-            sum(rnod$emm.difference<0&rnod$p.emm<=0.05)/nsim,
-            sum((rnod$slope.node-rnod$slope.others)>0&rnod$p.slope<=0.05)/nsim,
-            sum((rnod$slope.node-rnod$slope.others)<0&rnod$p.slope<=0.05)/nsim)->p.rate.node.y[j,]
+        p.phen.node.y<-matrix(ncol=7,nrow=iter)
+        p.rate.node.y<-matrix(ncol=5,nrow=iter)
+        for(w in 1:iter){
+          as.data.frame(do.call(rbind,lapply(phen.pran,function(x) x[w,])))->pnod
+          as.data.frame(do.call(rbind,lapply(rat.pran,function(x) x[w,])))->rnod
+
+          c(sum(pnod$slope>0&pnod$p.slope>=0.975)/nrow(pnod),
+            sum(pnod$slope>0&pnod$p.slope<=0.025)/nrow(pnod),
+            sum(pnod$slope<0&pnod$p.slope>=0.975)/nrow(pnod),
+            sum(pnod$slope<0&pnod$p.slope<=0.025)/nrow(pnod),
+            sum(pnod$emm.difference>0&pnod$p.emm<=0.05)/nrow(pnod),
+            sum(pnod$emm.difference<0&pnod$p.emm<=0.05)/nrow(pnod),
+            nrow(pnod)/nsim)->p.phen.node.y[w,]
+
+          c(sum(rnod$emm.difference>0&rnod$p.emm<=0.05)/nrow(rnod),
+            sum(rnod$emm.difference<0&rnod$p.emm<=0.05)/nrow(rnod),
+            sum((rnod$slope.node-rnod$slope.others)>0&rnod$p.slope<=0.05)/nrow(rnod),
+            sum((rnod$slope.node-rnod$slope.others)<0&rnod$p.slope<=0.05)/nrow(rnod),
+            nrow(rnod)/nsim)->p.rate.node.y[w,]
         }
-
-        colnames(p.phen.node.y)<-c("slope+p.up","slope+p.down","slope-p.up","slope-p.down","p.emm+","p.emm-")
-        colnames(p.rate.node.y)<-c("p.emm+","p.emm-","p.slope+","p.slope-")
+        colnames(p.phen.node.y)<-c("slope+p.up","slope+p.down","slope-p.up","slope-p.down","p.emm+","p.emm-","tested.trees")
+        colnames(p.rate.node.y)<-c("p.emm+","p.emm-","p.slope+","p.slope-","tested.trees")
         if(!is.null(colnames(y))){
           if(ncol(y)==1) colnam<-colnames(y) else colnam<-c(colnames(y),"multiple")
         }else{
@@ -604,70 +696,122 @@ overfitRR<-function(RR,y,
         }
         rownames(p.phen.node.y)<-rownames(p.rate.node.y)<-colnam
 
-        p.phen.node.y->p.phen.node[[i]]
-        p.rate.node.y->p.rate.node[[i]]
-
+        p.phen.node.y->p.phen.node[[k]]
+        p.rate.node.y->p.rate.node[[k]]
       }
       names(p.phen.node)<-names(p.rate.node)<-trend.node
       list(p.phen.node,p.rate.node)->p.trend.node
       names(p.trend.node)<-c("phenotype","rates")
       node.res<-p.trend.node
 
-      if(length(STcut[[1]])==7){ #### Node comparison ####
-        lapply(lapply(STcut,"[[",6),"[[",1)->pcomptot
-        mapply(x=pcomptot,xx=trend.node.match,function(x,xx){
-          if(ncol(y)>1){
-            t(apply(x[[1]],1,function(fx)
-              xx[match(gsub("g","",fx[1:2]),xx[,2]),1]))->x[[1]][,1:2]
-            lapply(2:length(x), function(xw) x[[xw]][,1:2]<<-x[[1]][,1:2])
-          }else{
-            t(apply(x,1,function(fx)
-              xx[match(gsub("g","",fx[1:2]),xx[,2]),1]))->x[,1:2]
-          }
-          x
-        },SIMPLIFY = FALSE)->pcomptot
+      if(length(trend.node)>1){ #### Node comparison ####
 
-        lapply(lapply(STcut,"[[",6),"[[",2)->rcomptot
-        mapply(x=rcomptot,xx=trend.node.match,function(x,xx){
-          if(ncol(y)>1){
-            t(apply(x[[1]],1,function(fx)
-              xx[match(gsub("g","",fx[1:2]),xx[,2]),1]))->x[[1]][,1:2]
-            lapply(2:length(x), function(xw) x[[xw]][,1:2]<<-x[[1]][,1:2])
-          }else{
-            t(apply(x,1,function(fx)
-              xx[match(gsub("g","",fx[1:2]),xx[,2]),1]))->x[,1:2]
-          }
-          x
-        },SIMPLIFY = FALSE)->rcomptot
+        apply(combn(trend.node,2),2,function(j) c(paste(j[1],j[2],sep="-"),paste(j[2],j[1],sep="-")))->tn.pairs
 
-        comp.phen.y<-comp.rat.y<-nod.nam<-list()
+        lapply(STcut,function(j) j$group.comparison)->comptot
+
+        mapply(x=lapply(comptot,"[[",1)[!sapply(comptot,is.null)],
+               xx=trend.node.match[!sapply(comptot,is.null)],function(x,xx){
+                 if(ncol(y)>1){
+                   t(apply(x[[1]],1,function(fx) xx[match(gsub("g","",fx[1:2]),xx[,2]),1]))->x[[1]][,1:2]
+                   lapply(2:length(x), function(xw) x[[xw]][,1:2]<<-x[[1]][,1:2])
+                   apply(x[[1]][,1:2],1,function(fx) paste(fx,collapse="-"))->realn
+                   unlist(apply(tn.pairs,2,function(jj) which(realn%in%jj)))->roword
+                   lapply(x,function(fx) fx[roword,])->x
+                   realn[roword]->realn
+                   apply(tn.pairs,2,function(jj) sum(match(realn,jj,nomatch = 0)))->revcols
+                   revcols[which(revcols>0)]->revcols
+
+                   lapply(x,function(kk){
+                     if(any(revcols==2)){
+                       data.frame(kk[which(revcols==2),c(2,1,4,3)],1-kk[which(revcols==2),5],
+                                  -1*kk[which(revcols==2),6],kk[which(revcols==2),7])->kk[which(revcols==2),]
+                     }
+                     data.frame(kk,pair=apply(kk[,1:2],1,function(jk) paste(jk,collapse = "-")))
+                   })
+                 }else{
+                   t(apply(x,1,function(fx) xx[match(gsub("g","",fx[1:2]),xx[,2]),1]))->x[,1:2]
+                   apply(x[,1:2],1,function(fx) paste(fx,collapse="-"))->realn
+                   unlist(apply(tn.pairs,2,function(jj) which(realn%in%jj)))->roword
+                   x[roword,]->x
+                   realn[roword]->realn
+                   apply(tn.pairs,2,function(jj) sum(match(realn,jj,nomatch = 0)))->revcols
+
+                   revcols[which(revcols>0)]->revcols
+                   if(any(revcols==2)){
+                     data.frame(x[which(revcols==2),c(2,1)],-1*x[which(revcols==2),3],
+                                x[which(revcols==2),c(4,6,5,7)])->x[which(revcols==2),]
+                   }
+                   data.frame(x,pair=apply(x[,1:2],1,function(jk) paste(jk,collapse = "-")))
+                 }
+               },SIMPLIFY = FALSE)->pcomptot
+
+        mapply(x=lapply(comptot,"[[",2)[!sapply(comptot,is.null)],
+               xx=trend.node.match[!sapply(comptot,is.null)],function(x,xx){
+                 if(ncol(y)>1){
+                   t(apply(x[[1]],1,function(fx) xx[match(gsub("g","",fx[1:2]),xx[,2]),1]))->x[[1]][,1:2]
+                   lapply(2:length(x), function(xw) x[[xw]][,1:2]<<-x[[1]][,1:2])
+                   apply(x[[1]][,1:2],1,function(fx) paste(fx,collapse="-"))->realn
+                   unlist(apply(tn.pairs,2,function(jj) which(realn%in%jj)))->roword
+                   lapply(x,function(fx) fx[roword,])->x
+                   realn[roword]->realn
+                   apply(tn.pairs,2,function(jj) sum(match(realn,jj,nomatch = 0)))->revcols
+                   revcols[which(revcols>0)]->revcols
+
+                   lapply(x,function(kk){
+                     if(any(revcols==2)){
+                       data.frame(kk[which(revcols==2),c(2,1)],-1*kk[which(revcols==2),3],kk[which(revcols==2),c(4,6,5,7)])->kk[which(revcols==2),]
+                     }
+                     data.frame(kk,pair=apply(kk[,1:2],1,function(jk) paste(jk,collapse = "-")))
+                   })
+                 }else{
+                   t(apply(x,1,function(fx) xx[match(gsub("g","",fx[1:2]),xx[,2]),1]))->x[,1:2]
+                   apply(x[,1:2],1,function(fx) paste(fx,collapse="-"))->realn
+                   unlist(apply(tn.pairs,2,function(jj) which(realn%in%jj)))->roword
+                   x[roword,]->x
+                   realn[roword]->realn
+                   apply(tn.pairs,2,function(jj) sum(match(realn,jj,nomatch = 0)))->revcols
+                   revcols[which(revcols>0)]->revcols
+
+                   if(any(revcols==2)){
+                     data.frame(x[which(revcols==2),c(2,1)],-1*x[which(revcols==2),3],
+                                x[which(revcols==2),c(4,6,5,7)])->x[which(revcols==2),]
+                   }
+                   data.frame(x,pair=apply(x[,1:2],1,function(jk) paste(jk,collapse = "-")))
+                 }
+               },SIMPLIFY = FALSE)->rcomptot
+
+
+        comp.phen.y<-comp.rat.y<-list()
         for(w in 1:iter){
           nod.nam<-list()
-          p.comp.phen<-p.comp.rat<-matrix(ncol=4,nrow=ncol(combn(trend.node,2)))
-          for(k in 1:ncol(combn(trend.node,2))){
+          p.comp.phen<-p.comp.rat<-matrix(ncol=5,nrow=ncol(tn.pairs))
+          for(k in 1:ncol(tn.pairs)){
             if(ncol(y)>1)
-              do.call(rbind,lapply(lapply(pcomptot,"[[",w),function(x) x[k,]))->pcomp else
-                do.call(rbind,lapply(pcomptot,function(x) x[k,]))->pcomp
+              do.call(rbind,lapply(lapply(pcomptot,"[[",w),function(x) x[which(x$pair==tn.pairs[1,k]),]))->pcomp else
+                do.call(rbind,lapply(pcomptot,function(x) x[which(x$pair==tn.pairs[1,k]),]))->pcomp
 
-            if(w==1) pcomp[nsim,1:2]->nod.nam[[k]]
+            if(w==1) pcomp[nrow(pcomp),1:2]->nod.nam[[k]]
             as.data.frame(pcomp[,3:7])->pcomp#->phen.comp[[k]]
             if(ncol(y)>1)
-              do.call(rbind,lapply(lapply(rcomptot,"[[",w),function(x) x[k,]))[,3:7,drop=FALSE]->rcomp else
-                do.call(rbind,lapply(rcomptot,function(x) x[k,]))[,3:7,drop=FALSE]->rcomp
+              do.call(rbind,lapply(lapply(rcomptot,"[[",w),function(x) x[which(x$pair==tn.pairs[1,k]),]))[,3:7,drop=FALSE]->rcomp else
+                do.call(rbind,lapply(rcomptot,function(x) x[which(x$pair==tn.pairs[1,k]),]))[,3:7,drop=FALSE]->rcomp
 
-            c(sum((pcomp$slope.group_1-pcomp$slope.group_2)>0&pcomp$p.slope>=0.95)/nsim,
-              sum((pcomp$slope.group_1-pcomp$slope.group_2)<0&pcomp$p.slope<=0.05)/nsim,
-              sum(pcomp$emm.difference>0&pcomp$p.emm<=0.05)/nsim,
-              sum(pcomp$emm.difference<0&pcomp$p.emm<=0.05)/nsim)->p.comp.phen[k,]
+            c(sum((pcomp$slope.group_1-pcomp$slope.group_2)>0&pcomp$p.slope>=0.95)/nrow(pcomp),
+              sum((pcomp$slope.group_1-pcomp$slope.group_2)<0&pcomp$p.slope<=0.05)/nrow(pcomp),
+              sum(pcomp$emm.difference>0&pcomp$p.emm<=0.05)/nrow(pcomp),
+              sum(pcomp$emm.difference<0&pcomp$p.emm<=0.05)/nrow(pcomp),
+              nrow(pcomp)/nsim)->p.comp.phen[k,]
 
-            c(sum(rcomp$emm.difference>0&rcomp$p.emm<=0.05)/nsim,
-              sum(rcomp$emm.difference<0&rcomp$p.emm<=0.05)/nsim,
-              sum((rcomp$slope.group_1-rcomp$slope.group_2)>0&rcomp$p.slope<=0.05)/nsim,
-              sum((rcomp$slope.group_1-rcomp$slope.group_2)<0&rcomp$p.slope<=0.05)/nsim)->p.comp.rat[k,]
+            c(sum(rcomp$emm.difference>0&rcomp$p.emm<=0.05)/nrow(rcomp),
+              sum(rcomp$emm.difference<0&rcomp$p.emm<=0.05)/nrow(rcomp),
+              sum((rcomp$slope.group_1-rcomp$slope.group_2)>0&rcomp$p.slope<=0.05)/nrow(rcomp),
+              sum((rcomp$slope.group_1-rcomp$slope.group_2)<0&rcomp$p.slope<=0.05)/nrow(rcomp),
+              nrow(rcomp)/nsim)->p.comp.rat[k,]
 
           }
-          colnames(p.comp.phen)<-c("p.slope+","p.slope-","p.emm+","p.emm-")
-          colnames(p.comp.rat)<-c("p.emm+","p.emm-","p.slope+","p.slope-")
+          colnames(p.comp.phen)<-c("p.slope+","p.slope-","p.emm+","p.emm-","tested.trees")
+          colnames(p.comp.rat)<-c("p.emm+","p.emm-","p.slope+","p.slope-","tested.trees")
           if(w==1) do.call(rbind, nod.nam)->nam.pair
 
           rownames(p.comp.phen)<-rownames(p.comp.rat)<-apply(nam.pair,1, function(x) paste(x[1], x[2], sep="-"))
@@ -676,9 +820,9 @@ overfitRR<-function(RR,y,
           p.comp.rat->comp.rat.y[[w]]
 
         }
-        p.comp.phenN<-p.comp.ratN<-list()
 
-        for(q in 1:ncol(combn(trend.node,2))){
+        p.comp.phenN<-p.comp.ratN<-list()
+        for(q in 1:ncol(tn.pairs)){
           do.call(rbind,lapply(comp.phen.y,function(x) x[q,]))->p.comp.phenN[[q]]
           do.call(rbind,lapply(comp.rat.y,function(x) x[q,]))->p.comp.ratN[[q]]
 
@@ -705,26 +849,30 @@ overfitRR<-function(RR,y,
   }else trend.res<-NULL
 
   if(!is.null(conv.node)){
-    matrix(c(length(which(lapply(lapply(SCcut,"[[",1),function(x) x[1,8])<=0.05))/nsim,
-             length(which(lapply(lapply(SCcut,"[[",1),function(x) x[1,9])<=0.05))/nsim),ncol=2)->p.convC
-    colnames(p.convC)<-colnames(SCcut[[1]][[1]])[8:9]
+    lapply(SCcut,"[[",1)->scres
+    scres[which(!sapply(SCcut,is.null))]->scres
+    matrix(c(length(which(lapply(scres,function(x) x[1,8])<=0.05))/length(scres),
+             length(which(lapply(scres,function(x) x[1,9])<=0.05))/length(scres),
+             length(scres)/nsim),ncol=3)->p.convC
+    colnames(p.convC)<-c("p.ang.bydist","p.ang.conv","tested.trees")
     rownames(p.convC)<-paste(conv.node,collapse="-")
   }else p.convC<-NULL
 
   if(!is.null(conv.state)){
-    p.convS<-matrix(ncol=2,nrow=nrow(SCcutS[[1]]))
+    lapply(SCcutS,"[[",1)->scresS
+    p.convS<-matrix(ncol=2,nrow=nrow(scresS[[1]]))
     if("nostate"%in%conv.state&length(unique(conv.state)[-which(unique(conv.state)=="nostate")])){
-      c(length(which(sapply(SCcutS,function(x) x[1,3])<=0.05))/nsim,
-        length(which(sapply(SCcutS,function(x) x[1,4])<=0.05))/nsim)->p.convS[1,]
-      rownames(p.convS)<-rownames(SCcutS[[1]])
-      colnames(p.convS)<-colnames(SCcutS[[1]])[3:4]
+      c(length(which(sapply(scresS,function(x) x[1,3])<=0.05))/nsim,
+        length(which(sapply(scresS,function(x) x[1,4])<=0.05))/nsim)->p.convS[1,]
+      rownames(p.convS)<-rownames(scresS[[1]])
+      colnames(p.convS)<-colnames(scresS[[1]])[3:4]
     }else{
-      for(i in 1:nrow(SCcutS[[1]])){
-        c(length(which(sapply(SCcutS,function(x) x[i,5])<=0.05))/nsim,
-          length(which(sapply(SCcutS,function(x) x[i,6])<=0.05))/nsim)->p.convS[i,]
+      for(i in 1:nrow(scresS[[1]])){
+        c(length(which(sapply(scresS,function(x) x[i,5])<=0.05))/nsim,
+          length(which(sapply(scresS,function(x) x[i,6])<=0.05))/nsim)->p.convS[i,]
       }
-      rownames(p.convS)<-apply(SCcutS[[1]][,1:2],1,function(x) paste(x[1],x[2],sep="-"))
-      colnames(p.convS)<-colnames(SCcutS[[1]])[5:6]
+      rownames(p.convS)<-apply(scresS[[1]][,1:2],1,function(x) paste(x[1],x[2],sep="-"))
+      colnames(p.convS)<-colnames(scresS[[1]])[5:6]
     }
 
   }else p.convS<-NULL
